
exports.up = async function(knex, Promise) {
    await knex.schema.renameTable("posts", "messages");
    await knex.schema.table('messages', function(table){
        table.renameColumn('description', 'content');
    });
    await knex.schema.createTable('announcements', function (table){
        table.inherits('messages');
    });
    await knex.schema.createTable('events', function (table){
        table.inherits('messages');
        table.string('location');
        table.dateTime('start_time');
        table.dateTime('end_time');
        table.boolean('is_announcement');
    });
    await knex.schema.createTable('group_message_relationships', function(table){
        table.integer('message').notNullable();
        table.string('group').notNullable();
        table.enum('status', ['join', 'host', 'publish']).notNullable();
    });
    await knex.schema.createTable('user_participation', function(table){
        table.integer('event').notNullable();
        table.string('user_uid').notNullable();
        table.enum('user_db', ['ldap']).notNullable().defaultTo('ldap');
    });
    return;
};

exports.down = async function(knex, Promise) {
    await knex.schema.dropTable('group_message_relationships');
    await knex.schema.dropTable('user_participation');
    let event_posts = await knex.select().from('events');
    let announcment_posts = await knex.select().from('announcements');
    await knex.schema.dropTable('events');
    await knex.schema.dropTable('announcements');
    await knex.schema.renameTable('messages', 'posts');
    await knex.schema.table('posts', function(table){
        table.renameColumn('content', 'description');
    });
    await knex('messages').insert(event_posts);
    await knex('messages').insert(announcment_posts);
    return;
};
